<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: output.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.OutputAction</code>
 */
class OutputAction extends \Google\Protobuf\Internal\Message
{
    /**
     * Default 0: NotSet
     *
     * Generated from protobuf field <code>uint32 ActiveMs = 1;</code>
     */
    protected $ActiveMs = 0;
    /**
     * Both InactiveMs and Repetitions must be set in order to repeat the switching between active and inactive
     *
     * Generated from protobuf field <code>uint32 InactiveMs = 5;</code>
     */
    protected $InactiveMs = 0;
    /**
     * Default 0: How many times must it Activate and Deactivate the output.
     *
     * Generated from protobuf field <code>uint32 Repetitions = 6;</code>
     */
    protected $Repetitions = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $ActiveMs
     *           Default 0: NotSet
     *     @type int $InactiveMs
     *           Both InactiveMs and Repetitions must be set in order to repeat the switching between active and inactive
     *     @type int $Repetitions
     *           Default 0: How many times must it Activate and Deactivate the output.
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Output::initOnce();
        parent::__construct($data);
    }

    /**
     * Default 0: NotSet
     *
     * Generated from protobuf field <code>uint32 ActiveMs = 1;</code>
     * @return int
     */
    public function getActiveMs()
    {
        return $this->ActiveMs;
    }

    /**
     * Default 0: NotSet
     *
     * Generated from protobuf field <code>uint32 ActiveMs = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setActiveMs($var)
    {
        GPBUtil::checkUint32($var);
        $this->ActiveMs = $var;

        return $this;
    }

    /**
     * Both InactiveMs and Repetitions must be set in order to repeat the switching between active and inactive
     *
     * Generated from protobuf field <code>uint32 InactiveMs = 5;</code>
     * @return int
     */
    public function getInactiveMs()
    {
        return $this->InactiveMs;
    }

    /**
     * Both InactiveMs and Repetitions must be set in order to repeat the switching between active and inactive
     *
     * Generated from protobuf field <code>uint32 InactiveMs = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setInactiveMs($var)
    {
        GPBUtil::checkUint32($var);
        $this->InactiveMs = $var;

        return $this;
    }

    /**
     * Default 0: How many times must it Activate and Deactivate the output.
     *
     * Generated from protobuf field <code>uint32 Repetitions = 6;</code>
     * @return int
     */
    public function getRepetitions()
    {
        return $this->Repetitions;
    }

    /**
     * Default 0: How many times must it Activate and Deactivate the output.
     *
     * Generated from protobuf field <code>uint32 Repetitions = 6;</code>
     * @param int $var
     * @return $this
     */
    public function setRepetitions($var)
    {
        GPBUtil::checkUint32($var);
        $this->Repetitions = $var;

        return $this;
    }

}

