<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: led.proto

namespace GPBMetadata;

class Led
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        $pool->internalAddGeneratedFile(
            "\x0A\xA9\x01\x0A\x09led.proto\x12\x05OS.PB\"S\x0A\x09LEDAction\x12\x0D\x0A\x05Color\x18\x01 \x01(\x0D\x12\x12\x0A\x0ADurationMs\x18\x05 \x01(\x0D\x12\x0F\x0A\x07BlinkMs\x18\x06 \x01(\x0D\x12\x12\x0A\x0ABlinkOffMs\x18\x07 \x01(\x0D\"4\x0A\x09LEDConfig\x12\x13\x0A\x0BSteadyColor\x18\x01 \x01(\x0D\x12\x12\x0A\x0ADurationMs\x18\x02 \x01(\x0DB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

