<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 **
 * \@brief: Configure a button for a particular Care Link
 * 
 * \@details: If a button is configured on this Care Link when it is assigned to a room (or rooms)
 *
 * Generated from protobuf message <code>OS.PB.HealthLinkButtonConfig</code>
 */
class HealthLinkButtonConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * Serial of the Patient button to look out for to activate relevant lights
     *
     * Generated from protobuf field <code>uint32 Serial = 1;</code>
     */
    protected $Serial = 0;
    /**
     * (Require 1 at least) Activate the path of lights belonging to the patient's bed or room.
     *
     * Generated from protobuf field <code>repeated uint64 LightIds = 4;</code>
     */
    private $LightIds;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $Serial
     *           Serial of the Patient button to look out for to activate relevant lights
     *     @type int[]|string[] $LightIds
     *           (Require 1 at least) Activate the path of lights belonging to the patient's bed or room.
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Health::initOnce();
        parent::__construct($data);
    }

    /**
     * Serial of the Patient button to look out for to activate relevant lights
     *
     * Generated from protobuf field <code>uint32 Serial = 1;</code>
     * @return int
     */
    public function getSerial()
    {
        return $this->Serial;
    }

    /**
     * Serial of the Patient button to look out for to activate relevant lights
     *
     * Generated from protobuf field <code>uint32 Serial = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setSerial($var)
    {
        GPBUtil::checkUint32($var);
        $this->Serial = $var;

        return $this;
    }

    /**
     * (Require 1 at least) Activate the path of lights belonging to the patient's bed or room.
     *
     * Generated from protobuf field <code>repeated uint64 LightIds = 4;</code>
     * @return RepeatedField<int>|RepeatedField<string>
     */
    public function getLightIds()
    {
        return $this->LightIds;
    }

    /**
     * (Require 1 at least) Activate the path of lights belonging to the patient's bed or room.
     *
     * Generated from protobuf field <code>repeated uint64 LightIds = 4;</code>
     * @param int[]|string[] $var
     * @return $this
     */
    public function setLightIds($var)
    {
        $arr = GPBUtil::checkRepeatedField($var, \Google\Protobuf\Internal\GPBType::UINT64);
        $this->LightIds = $arr;

        return $this;
    }

}

