<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: action.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 **
 * \@brief Used for unit testing that sets a value 
 *
 * Generated from protobuf message <code>OS.PB.TestAction</code>
 */
class TestAction extends \Google\Protobuf\Internal\Message
{
    /**
     * Generated from protobuf field <code>uint32 TestValue = 1;</code>
     */
    protected $TestValue = 0;
    /**
     * Generated from protobuf field <code>bytes TestBuffer = 2;</code>
     */
    protected $TestBuffer = '';

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $TestValue
     *     @type string $TestBuffer
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Action::initOnce();
        parent::__construct($data);
    }

    /**
     * Generated from protobuf field <code>uint32 TestValue = 1;</code>
     * @return int
     */
    public function getTestValue()
    {
        return $this->TestValue;
    }

    /**
     * Generated from protobuf field <code>uint32 TestValue = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setTestValue($var)
    {
        GPBUtil::checkUint32($var);
        $this->TestValue = $var;

        return $this;
    }

    /**
     * Generated from protobuf field <code>bytes TestBuffer = 2;</code>
     * @return string
     */
    public function getTestBuffer()
    {
        return $this->TestBuffer;
    }

    /**
     * Generated from protobuf field <code>bytes TestBuffer = 2;</code>
     * @param string $var
     * @return $this
     */
    public function setTestBuffer($var)
    {
        GPBUtil::checkString($var, False);
        $this->TestBuffer = $var;

        return $this;
    }

}

