<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto

namespace GPBMetadata;

class Health
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Device::initOnce();
        \GPBMetadata\Types::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xB4\x0B\x0A\x0Chealth.proto\x12\x05OS.PB\x1A\x0Btypes.proto\"\xCB\x02\x0A\x11HealthButtonEvent\x12\x0E\x0A\x06Serial\x18\x01 \x01(\x0D\x12\x0F\x0A\x07AlertId\x18\x02 \x01(\x0D\x12\x15\x0A\x0DPatientSerial\x18\x03 \x01(\x0D\x12%\x0A\x04Role\x18\x04 \x01(\x0E2\x17.OS.PB.HealthButtonRole\x12\x0C\x0A\x04RSSI\x18\x05 \x01(\x11\x12\x0F\x0A\x07TxPower\x18\x06 \x01(\x11\x12\x16\x0A\x0EBatteryVoltage\x18\x07 \x01(\x0D\x12'\x0A\x05Flags\x18\x08 \x01(\x0E2\x18.OS.PB.HealthButtonFlags\x12\x10\x0A\x08LightIds\x18\x09 \x03(\x04\x124\x0A\x09Distances\x18\x0A \x03(\x0B2!.OS.PB.HealthButtonEvent.Distance\x1A/\x0A\x08Distance\x12\x0E\x0A\x06Serial\x18\x01 \x01(\x0D\x12\x13\x0A\x0BMeasurement\x18\x02 \x01(\x0D\":\x0A\x16HealthLinkButtonConfig\x12\x0E\x0A\x06Serial\x18\x01 \x01(\x0D\x12\x10\x0A\x08LightIds\x18\x04 \x03(\x04\"\x90\x01\x0A\x15HealthLinkLightConfig\x12\x0A\x0A\x02Id\x18\x01 \x01(\x04\x12)\x0A\x09Interface\x18\x05 \x01(\x0E2\x16.OS.PB.DeviceInterface\x12\x16\x0A\x0EInterfaceIndex\x18\x06 \x01(\x0D\x12\x16\x0A\x0ELogicalAddress\x18\x0A \x01(\x0D\x12\x10\x0A\x08OutputNo\x18\x0B \x01(\x0D\"z\x0A\x0FHealthLinkEvent\x12\x0F\x0A\x07LightId\x18\x01 \x01(\x04\x12,\x0A\x06Alerts\x18\x05 \x03(\x0B2\x1C.OS.PB.HealthLinkEvent.Alert\x1A(\x0A\x05Alert\x12\x0E\x0A\x06Serial\x18\x01 \x01(\x0D\x12\x0F\x0A\x07AlertId\x18\x02 \x01(\x0D\"K\x0A\x10HealthLinkAction\x12\x10\x0A\x08LightIds\x18\x01 \x03(\x04\x12\x14\x0A\x0CButtonSerial\x18\x02 \x01(\x0D\x12\x0F\x0A\x07AlertId\x18\x03 \x01(\x0D\"\xBB\x01\x0A\x10HealthLinkConfig\x12\x1C\x0A\x05State\x18\x01 \x01(\x0E2\x0D.OS.PB.Toggle\x12#\x0A\x04Role\x18\x02 \x01(\x0E2\x15.OS.PB.HealthLinkRole\x12\x15\x0A\x0DStationLinkId\x18\x04 \x01(\x04\x12\x10\x0A\x08LightIds\x18\x0A \x03(\x04\x12\x1D\x0A\x15VicinityRSSIThreshold\x18\x0B \x01(\x11\x12\x1C\x0A\x14MonitorRSSIThreshold\x18\x0D \x01(\x11*\x98\x01\x0A\x10HealthButtonRole\x12\x1B\x0A\x17HealthButtonRole_NotSet\x10\x00\x12\x18\x0A\x14HealthButton_Patient\x10\x01\x12\x16\x0A\x12HealthButton_Staff\x10\x02\x12\x1A\x0A\x16HealthButton_Monitored\x10\x03\x12\x19\x0A\x15HealthButton_Personal\x10\x04*\xA2\x01\x0A\x11HealthButtonFlags\x12\x1C\x0A\x18HealthButtonFlags_NotSet\x10\x00\x12\x19\x0A\x15HealthButton_BrownOut\x10\x01\x12\x16\x0A\x12HealthButton_Fault\x10\x02\x12\x1B\x0A\x17HealthButton_Configured\x10\x10\x12\x1F\x0A\x1BHealthButton_Brownout_Fault\x10\x03*\x9F\x01\x0A\x0EHealthLinkRole\x12\x19\x0A\x15HealthLinkRole_NotSet\x10\x00\x12\x13\x0A\x0FHealthLink_Care\x10\x01\x12\x18\x0A\x14HealthLink_Monitored\x10\x03\x12\x16\x0A\x12HealthLink_Station\x10\x05\x12\x13\x0A\x0FHealthLink_Home\x10\x10\x12\x16\x0A\x12HealthLink_Village\x10\x11B\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

