<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.HealthLinkLightConfig</code>
 */
class HealthLinkLightConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * The Id of the light configured.
     *
     * Generated from protobuf field <code>uint64 Id = 1;</code>
     */
    protected $Id = 0;
    /**
     * Which interface is the light connected to. Options: Relay, Output, RS485
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 5;</code>
     */
    protected $Interface = 0;
    /**
     * Which interface index is light on.
     *
     * Generated from protobuf field <code>uint32 InterfaceIndex = 6;</code>
     */
    protected $InterfaceIndex = 0;
    /**
     * Following for RS485 only (OSDP/ModBus RTU)
     *
     * Generated from protobuf field <code>uint32 LogicalAddress = 10;</code>
     */
    protected $LogicalAddress = 0;
    /**
     * Which output (Relay/Open-collector) on the device to activate or deactivate. 
     *
     * Generated from protobuf field <code>uint32 OutputNo = 11;</code>
     */
    protected $OutputNo = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int|string $Id
     *           The Id of the light configured.
     *     @type int $Interface
     *           Which interface is the light connected to. Options: Relay, Output, RS485
     *     @type int $InterfaceIndex
     *           Which interface index is light on.
     *     @type int $LogicalAddress
     *           Following for RS485 only (OSDP/ModBus RTU)
     *     @type int $OutputNo
     *           Which output (Relay/Open-collector) on the device to activate or deactivate. 
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Health::initOnce();
        parent::__construct($data);
    }

    /**
     * The Id of the light configured.
     *
     * Generated from protobuf field <code>uint64 Id = 1;</code>
     * @return int|string
     */
    public function getId()
    {
        return $this->Id;
    }

    /**
     * The Id of the light configured.
     *
     * Generated from protobuf field <code>uint64 Id = 1;</code>
     * @param int|string $var
     * @return $this
     */
    public function setId($var)
    {
        GPBUtil::checkUint64($var);
        $this->Id = $var;

        return $this;
    }

    /**
     * Which interface is the light connected to. Options: Relay, Output, RS485
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 5;</code>
     * @return int
     */
    public function getInterface()
    {
        return $this->Interface;
    }

    /**
     * Which interface is the light connected to. Options: Relay, Output, RS485
     *
     * Generated from protobuf field <code>.OS.PB.DeviceInterface Interface = 5;</code>
     * @param int $var
     * @return $this
     */
    public function setInterface($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\DeviceInterface::class);
        $this->Interface = $var;

        return $this;
    }

    /**
     * Which interface index is light on.
     *
     * Generated from protobuf field <code>uint32 InterfaceIndex = 6;</code>
     * @return int
     */
    public function getInterfaceIndex()
    {
        return $this->InterfaceIndex;
    }

    /**
     * Which interface index is light on.
     *
     * Generated from protobuf field <code>uint32 InterfaceIndex = 6;</code>
     * @param int $var
     * @return $this
     */
    public function setInterfaceIndex($var)
    {
        GPBUtil::checkUint32($var);
        $this->InterfaceIndex = $var;

        return $this;
    }

    /**
     * Following for RS485 only (OSDP/ModBus RTU)
     *
     * Generated from protobuf field <code>uint32 LogicalAddress = 10;</code>
     * @return int
     */
    public function getLogicalAddress()
    {
        return $this->LogicalAddress;
    }

    /**
     * Following for RS485 only (OSDP/ModBus RTU)
     *
     * Generated from protobuf field <code>uint32 LogicalAddress = 10;</code>
     * @param int $var
     * @return $this
     */
    public function setLogicalAddress($var)
    {
        GPBUtil::checkUint32($var);
        $this->LogicalAddress = $var;

        return $this;
    }

    /**
     * Which output (Relay/Open-collector) on the device to activate or deactivate. 
     *
     * Generated from protobuf field <code>uint32 OutputNo = 11;</code>
     * @return int
     */
    public function getOutputNo()
    {
        return $this->OutputNo;
    }

    /**
     * Which output (Relay/Open-collector) on the device to activate or deactivate. 
     *
     * Generated from protobuf field <code>uint32 OutputNo = 11;</code>
     * @param int $var
     * @return $this
     */
    public function setOutputNo($var)
    {
        GPBUtil::checkUint32($var);
        $this->OutputNo = $var;

        return $this;
    }

}

