<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: led.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.LEDConfig</code>
 */
class LEDConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * The Color in standard hex code 0xRRGGBB for the LED when no action is in play. 0 for all LEDs to be disabled.
     *
     * Generated from protobuf field <code>uint32 SteadyColor = 1;</code>
     */
    protected $SteadyColor = 0;
    /**
     * The default duration if no duration is set in the LEDAction message.
     *
     * Generated from protobuf field <code>uint32 DurationMs = 2;</code>
     */
    protected $DurationMs = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $SteadyColor
     *           The Color in standard hex code 0xRRGGBB for the LED when no action is in play. 0 for all LEDs to be disabled.
     *     @type int $DurationMs
     *           The default duration if no duration is set in the LEDAction message.
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Led::initOnce();
        parent::__construct($data);
    }

    /**
     * The Color in standard hex code 0xRRGGBB for the LED when no action is in play. 0 for all LEDs to be disabled.
     *
     * Generated from protobuf field <code>uint32 SteadyColor = 1;</code>
     * @return int
     */
    public function getSteadyColor()
    {
        return $this->SteadyColor;
    }

    /**
     * The Color in standard hex code 0xRRGGBB for the LED when no action is in play. 0 for all LEDs to be disabled.
     *
     * Generated from protobuf field <code>uint32 SteadyColor = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setSteadyColor($var)
    {
        GPBUtil::checkUint32($var);
        $this->SteadyColor = $var;

        return $this;
    }

    /**
     * The default duration if no duration is set in the LEDAction message.
     *
     * Generated from protobuf field <code>uint32 DurationMs = 2;</code>
     * @return int
     */
    public function getDurationMs()
    {
        return $this->DurationMs;
    }

    /**
     * The default duration if no duration is set in the LEDAction message.
     *
     * Generated from protobuf field <code>uint32 DurationMs = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setDurationMs($var)
    {
        GPBUtil::checkUint32($var);
        $this->DurationMs = $var;

        return $this;
    }

}

