<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: output.proto

namespace GPBMetadata;

class Output
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Types::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xAF\x01\x0A\x0Coutput.proto\x12\x05OS.PB\"I\x0A\x0COutputAction\x12\x10\x0A\x08ActiveMs\x18\x01 \x01(\x0D\x12\x12\x0A\x0AInactiveMs\x18\x05 \x01(\x0D\x12\x13\x0A\x0BRepetitions\x18\x06 \x01(\x0D\"A\x0A\x0COutputConfig\x12\x10\x0A\x08ActiveMs\x18\x01 \x01(\x0D\x12\x1F\x0A\x08Inverted\x18\x02 \x01(\x0E2\x0D.OS.PB.ToggleB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

