<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 **
 * \@brief: Configuration for OneHealth Link Devices
 *
 * Generated from protobuf message <code>OS.PB.HealthLinkConfig</code>
 */
class HealthLinkConfig extends \Google\Protobuf\Internal\Message
{
    /**
     * Default: Enabled. Whether OneHealth application is enabled or not on this device
     *
     * Generated from protobuf field <code>.OS.PB.Toggle State = 1;</code>
     */
    protected $State = 0;
    /**
     * Default: Depends on the BOARD used. 
     *
     * Generated from protobuf field <code>.OS.PB.HealthLinkRole Role = 2;</code>
     */
    protected $Role = 0;
    /**
     * Default: NotSet. Which Nurse Station Link to send a copy of events to.
     *
     * Generated from protobuf field <code>uint64 StationLinkId = 4;</code>
     */
    protected $StationLinkId = 0;
    /**
     * Default: NotSet. Whether or not this Care Link has a specific Light associated with it that represents a room.
     *
     * Generated from protobuf field <code>repeated uint64 LightIds = 10;</code>
     */
    private $LightIds;
    /**
     * Default: -60dBm. Automatically activate the Light if the button is configured on this link device and within this threshold.
     *
     * Generated from protobuf field <code>sint32 VicinityRSSIThreshold = 11;</code>
     */
    protected $VicinityRSSIThreshold = 0;
    /**
     * Default: -50dBm. Automatically send a Monitoring alert when RSSI threshold is met if monitored role.
     *
     * Generated from protobuf field <code>sint32 MonitorRSSIThreshold = 13;</code>
     */
    protected $MonitorRSSIThreshold = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $State
     *           Default: Enabled. Whether OneHealth application is enabled or not on this device
     *     @type int $Role
     *           Default: Depends on the BOARD used. 
     *     @type int|string $StationLinkId
     *           Default: NotSet. Which Nurse Station Link to send a copy of events to.
     *     @type int[]|string[] $LightIds
     *           Default: NotSet. Whether or not this Care Link has a specific Light associated with it that represents a room.
     *     @type int $VicinityRSSIThreshold
     *           Default: -60dBm. Automatically activate the Light if the button is configured on this link device and within this threshold.
     *     @type int $MonitorRSSIThreshold
     *           Default: -50dBm. Automatically send a Monitoring alert when RSSI threshold is met if monitored role.
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Health::initOnce();
        parent::__construct($data);
    }

    /**
     * Default: Enabled. Whether OneHealth application is enabled or not on this device
     *
     * Generated from protobuf field <code>.OS.PB.Toggle State = 1;</code>
     * @return int
     */
    public function getState()
    {
        return $this->State;
    }

    /**
     * Default: Enabled. Whether OneHealth application is enabled or not on this device
     *
     * Generated from protobuf field <code>.OS.PB.Toggle State = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setState($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\Toggle::class);
        $this->State = $var;

        return $this;
    }

    /**
     * Default: Depends on the BOARD used. 
     *
     * Generated from protobuf field <code>.OS.PB.HealthLinkRole Role = 2;</code>
     * @return int
     */
    public function getRole()
    {
        return $this->Role;
    }

    /**
     * Default: Depends on the BOARD used. 
     *
     * Generated from protobuf field <code>.OS.PB.HealthLinkRole Role = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setRole($var)
    {
        GPBUtil::checkEnum($var, \OS\PB\HealthLinkRole::class);
        $this->Role = $var;

        return $this;
    }

    /**
     * Default: NotSet. Which Nurse Station Link to send a copy of events to.
     *
     * Generated from protobuf field <code>uint64 StationLinkId = 4;</code>
     * @return int|string
     */
    public function getStationLinkId()
    {
        return $this->StationLinkId;
    }

    /**
     * Default: NotSet. Which Nurse Station Link to send a copy of events to.
     *
     * Generated from protobuf field <code>uint64 StationLinkId = 4;</code>
     * @param int|string $var
     * @return $this
     */
    public function setStationLinkId($var)
    {
        GPBUtil::checkUint64($var);
        $this->StationLinkId = $var;

        return $this;
    }

    /**
     * Default: NotSet. Whether or not this Care Link has a specific Light associated with it that represents a room.
     *
     * Generated from protobuf field <code>repeated uint64 LightIds = 10;</code>
     * @return RepeatedField<int>|RepeatedField<string>
     */
    public function getLightIds()
    {
        return $this->LightIds;
    }

    /**
     * Default: NotSet. Whether or not this Care Link has a specific Light associated with it that represents a room.
     *
     * Generated from protobuf field <code>repeated uint64 LightIds = 10;</code>
     * @param int[]|string[] $var
     * @return $this
     */
    public function setLightIds($var)
    {
        $arr = GPBUtil::checkRepeatedField($var, \Google\Protobuf\Internal\GPBType::UINT64);
        $this->LightIds = $arr;

        return $this;
    }

    /**
     * Default: -60dBm. Automatically activate the Light if the button is configured on this link device and within this threshold.
     *
     * Generated from protobuf field <code>sint32 VicinityRSSIThreshold = 11;</code>
     * @return int
     */
    public function getVicinityRSSIThreshold()
    {
        return $this->VicinityRSSIThreshold;
    }

    /**
     * Default: -60dBm. Automatically activate the Light if the button is configured on this link device and within this threshold.
     *
     * Generated from protobuf field <code>sint32 VicinityRSSIThreshold = 11;</code>
     * @param int $var
     * @return $this
     */
    public function setVicinityRSSIThreshold($var)
    {
        GPBUtil::checkInt32($var);
        $this->VicinityRSSIThreshold = $var;

        return $this;
    }

    /**
     * Default: -50dBm. Automatically send a Monitoring alert when RSSI threshold is met if monitored role.
     *
     * Generated from protobuf field <code>sint32 MonitorRSSIThreshold = 13;</code>
     * @return int
     */
    public function getMonitorRSSIThreshold()
    {
        return $this->MonitorRSSIThreshold;
    }

    /**
     * Default: -50dBm. Automatically send a Monitoring alert when RSSI threshold is met if monitored role.
     *
     * Generated from protobuf field <code>sint32 MonitorRSSIThreshold = 13;</code>
     * @param int $var
     * @return $this
     */
    public function setMonitorRSSIThreshold($var)
    {
        GPBUtil::checkInt32($var);
        $this->MonitorRSSIThreshold = $var;

        return $this;
    }

}

