<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.HealthLinkEvent</code>
 */
class HealthLinkEvent extends \Google\Protobuf\Internal\Message
{
    /**
     * If no LightId, then this is the default Light (Relay:0)
     *
     * Generated from protobuf field <code>uint64 LightId = 1;</code>
     */
    protected $LightId = 0;
    /**
     * Current Active Alerts for HealthLinkLight events.
     *
     * Generated from protobuf field <code>repeated .OS.PB.HealthLinkEvent.Alert Alerts = 5;</code>
     */
    private $Alerts;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int|string $LightId
     *           If no LightId, then this is the default Light (Relay:0)
     *     @type \OS\PB\HealthLinkEvent\Alert[] $Alerts
     *           Current Active Alerts for HealthLinkLight events.
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Health::initOnce();
        parent::__construct($data);
    }

    /**
     * If no LightId, then this is the default Light (Relay:0)
     *
     * Generated from protobuf field <code>uint64 LightId = 1;</code>
     * @return int|string
     */
    public function getLightId()
    {
        return $this->LightId;
    }

    /**
     * If no LightId, then this is the default Light (Relay:0)
     *
     * Generated from protobuf field <code>uint64 LightId = 1;</code>
     * @param int|string $var
     * @return $this
     */
    public function setLightId($var)
    {
        GPBUtil::checkUint64($var);
        $this->LightId = $var;

        return $this;
    }

    /**
     * Current Active Alerts for HealthLinkLight events.
     *
     * Generated from protobuf field <code>repeated .OS.PB.HealthLinkEvent.Alert Alerts = 5;</code>
     * @return RepeatedField<\OS\PB\HealthLinkEvent\Alert>
     */
    public function getAlerts()
    {
        return $this->Alerts;
    }

    /**
     * Current Active Alerts for HealthLinkLight events.
     *
     * Generated from protobuf field <code>repeated .OS.PB.HealthLinkEvent.Alert Alerts = 5;</code>
     * @param \OS\PB\HealthLinkEvent\Alert[] $var
     * @return $this
     */
    public function setAlerts($var)
    {
        $arr = GPBUtil::checkRepeatedField($var, \Google\Protobuf\Internal\GPBType::MESSAGE, \OS\PB\HealthLinkEvent\Alert::class);
        $this->Alerts = $arr;

        return $this;
    }

}

