<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto

namespace OS\PB\HealthButtonEvent;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.HealthButtonEvent.Distance</code>
 */
class Distance extends \Google\Protobuf\Internal\Message
{
    /**
     * Serial of Link device
     *
     * Generated from protobuf field <code>uint32 Serial = 1;</code>
     */
    protected $Serial = 0;
    /**
     * Average measurement
     *
     * Generated from protobuf field <code>uint32 Measurement = 2;</code>
     */
    protected $Measurement = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int $Serial
     *           Serial of Link device
     *     @type int $Measurement
     *           Average measurement
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Health::initOnce();
        parent::__construct($data);
    }

    /**
     * Serial of Link device
     *
     * Generated from protobuf field <code>uint32 Serial = 1;</code>
     * @return int
     */
    public function getSerial()
    {
        return $this->Serial;
    }

    /**
     * Serial of Link device
     *
     * Generated from protobuf field <code>uint32 Serial = 1;</code>
     * @param int $var
     * @return $this
     */
    public function setSerial($var)
    {
        GPBUtil::checkUint32($var);
        $this->Serial = $var;

        return $this;
    }

    /**
     * Average measurement
     *
     * Generated from protobuf field <code>uint32 Measurement = 2;</code>
     * @return int
     */
    public function getMeasurement()
    {
        return $this->Measurement;
    }

    /**
     * Average measurement
     *
     * Generated from protobuf field <code>uint32 Measurement = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setMeasurement($var)
    {
        GPBUtil::checkUint32($var);
        $this->Measurement = $var;

        return $this;
    }

}

