<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto

namespace OS\PB;

use Google\Protobuf\Internal\GPBType;
use Google\Protobuf\Internal\GPBUtil;
use Google\Protobuf\RepeatedField;

/**
 * Generated from protobuf message <code>OS.PB.HealthLinkAction</code>
 */
class HealthLinkAction extends \Google\Protobuf\Internal\Message
{
    /**
     * A list of Lights to activate, linked with a ButtonSerial and AlertId
     *
     * Generated from protobuf field <code>repeated uint64 LightIds = 1;</code>
     */
    private $LightIds;
    /**
     * This action is generally propagated from the Station Link device once a couple vicinity events have been received
     * If no Ids are provided on a HealthLightDeactivate action, then will clear alerts that match the ButtonSerial.
     *
     * Generated from protobuf field <code>uint32 ButtonSerial = 2;</code>
     */
    protected $ButtonSerial = 0;
    /**
     * Clear a matching AlertId on a button
     *
     * Generated from protobuf field <code>uint32 AlertId = 3;</code>
     */
    protected $AlertId = 0;

    /**
     * Constructor.
     *
     * @param array $data {
     *     Optional. Data for populating the Message object.
     *
     *     @type int[]|string[] $LightIds
     *           A list of Lights to activate, linked with a ButtonSerial and AlertId
     *     @type int $ButtonSerial
     *           This action is generally propagated from the Station Link device once a couple vicinity events have been received
     *           If no Ids are provided on a HealthLightDeactivate action, then will clear alerts that match the ButtonSerial.
     *     @type int $AlertId
     *           Clear a matching AlertId on a button
     * }
     */
    public function __construct($data = NULL) {
        \GPBMetadata\Health::initOnce();
        parent::__construct($data);
    }

    /**
     * A list of Lights to activate, linked with a ButtonSerial and AlertId
     *
     * Generated from protobuf field <code>repeated uint64 LightIds = 1;</code>
     * @return RepeatedField<int>|RepeatedField<string>
     */
    public function getLightIds()
    {
        return $this->LightIds;
    }

    /**
     * A list of Lights to activate, linked with a ButtonSerial and AlertId
     *
     * Generated from protobuf field <code>repeated uint64 LightIds = 1;</code>
     * @param int[]|string[] $var
     * @return $this
     */
    public function setLightIds($var)
    {
        $arr = GPBUtil::checkRepeatedField($var, \Google\Protobuf\Internal\GPBType::UINT64);
        $this->LightIds = $arr;

        return $this;
    }

    /**
     * This action is generally propagated from the Station Link device once a couple vicinity events have been received
     * If no Ids are provided on a HealthLightDeactivate action, then will clear alerts that match the ButtonSerial.
     *
     * Generated from protobuf field <code>uint32 ButtonSerial = 2;</code>
     * @return int
     */
    public function getButtonSerial()
    {
        return $this->ButtonSerial;
    }

    /**
     * This action is generally propagated from the Station Link device once a couple vicinity events have been received
     * If no Ids are provided on a HealthLightDeactivate action, then will clear alerts that match the ButtonSerial.
     *
     * Generated from protobuf field <code>uint32 ButtonSerial = 2;</code>
     * @param int $var
     * @return $this
     */
    public function setButtonSerial($var)
    {
        GPBUtil::checkUint32($var);
        $this->ButtonSerial = $var;

        return $this;
    }

    /**
     * Clear a matching AlertId on a button
     *
     * Generated from protobuf field <code>uint32 AlertId = 3;</code>
     * @return int
     */
    public function getAlertId()
    {
        return $this->AlertId;
    }

    /**
     * Clear a matching AlertId on a button
     *
     * Generated from protobuf field <code>uint32 AlertId = 3;</code>
     * @param int $var
     * @return $this
     */
    public function setAlertId($var)
    {
        GPBUtil::checkUint32($var);
        $this->AlertId = $var;

        return $this;
    }

}

